@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@ubiz.ru>
+ * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@ubiz.ru>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef TEMPLATEPARSER_CUSTOMTEMPLATESMENU_H
@@ -26,7 +14,8 @@
 class KActionCollection;
 class KActionMenu;
 
-namespace TemplateParser {
+namespace TemplateParser
+{
 class CustomTemplatesMenuPrivate;
 /**
  * @brief The CustomTemplatesMenu class
@@ -37,7 +26,7 @@ class TEMPLATEPARSER_EXPORT CustomTemplatesMenu : public QObject
 
 public:
     explicit CustomTemplatesMenu(QWidget *parent, KActionCollection *ac);
-    ~CustomTemplatesMenu();
+    ~CustomTemplatesMenu() override;
 
     KActionMenu *replyActionMenu() const;
     KActionMenu *replyAllActionMenu() const;
